@@ -1,7 +1,7 @@
 package Complete::Util;
 
 our $DATE = '2016-08-24'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,6 +54,7 @@ _
             pos => 1,
         },
     },
+    args_as => 'array',
     result_naked => 1,
     result => {
         schema => 'hash*',
@@ -90,6 +91,7 @@ _
             pos => 0,
         },
     },
+    args_as => 'array',
     result_naked => 1,
     result => {
         schema => 'array*',
@@ -586,14 +588,14 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.47 of Complete::Util (from Perl distribution Complete-Util), released on 2016-08-24.
+This document describes version 0.48 of Complete::Util (from Perl distribution Complete-Util), released on 2016-08-24.
 
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
 
 
-=head2 arrayify_answer(%args) -> array
+=head2 arrayify_answer($arg) -> array
 
 Make sure we return completion answer in array form.
 
@@ -606,7 +608,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<arg>* => I<array|hash>
+=item * B<$arg>* => I<array|hash>
 
 =back
 
@@ -752,7 +754,7 @@ Word to complete.
 Return value:  (array)
 
 
-=head2 hashify_answer(%args) -> hash
+=head2 hashify_answer($arg, $meta) -> hash
 
 Make sure we return completion answer in hash form.
 
@@ -768,9 +770,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<arg>* => I<array|hash>
+=item * B<$arg>* => I<array|hash>
 
-=item * B<meta> => I<hash>
+=item * B<$meta> => I<hash>
 
 Metadata (extra keys) for the hash.
 
